@@ -329,7 +329,7 @@ class MPRIS(DBusInterface):
         if self._player.props.repeat_mode == RepeatMode.ALL:
             return "Playlist"
         elif self._player.props.repeat_mode == RepeatMode.SONG:
-            return 'Track'
+            return "Track"
         else:
             return "None"
 
@@ -420,7 +420,7 @@ class MPRIS(DBusInterface):
         return path
 
     @log
-    def _update_songs_list(self):
+    def _update_tracklist(self):
         previous_path_list = self._path_list
         self._path_list = []
         self._metadata_list = []
@@ -529,7 +529,7 @@ class MPRIS(DBusInterface):
         if added == model.get_n_items():
             return
 
-        self._update_songs_list()
+        self._update_tracklist()
 
         properties = {}
         properties["Metadata"] = GLib.Variant("a{sv}", self._get_metadata())
@@ -565,7 +565,7 @@ class MPRIS(DBusInterface):
 
     @log
     def _on_repeat_mode_changed(self, player, param):
-        self._update_songs_list()
+        self._update_tracklist()
 
         properties = {}
 
