@@ -28,7 +28,7 @@ from gi.repository import GObject, Gtk
 from gnomemusic import log
 from gnomemusic.albumartcache import Art
 from gnomemusic.gstplayer import Playback
-from gnomemusic.player import RepeatMode
+from gnomemusic.player import Player, RepeatMode
 from gnomemusic.widgets.coverstack import CoverStack  # noqa: F401
 from gnomemusic.widgets.smoothscale import SmoothScale  # noqa: F401
 from gnomemusic.widgets.twolinetip import TwoLineTip
@@ -42,10 +42,6 @@ class PlayerToolbar(Gtk.ActionBar):
     Contains the ui of playing a song with Music.
     """
 
-    __gsignals__ = {
-        'thumbnail-updated': (GObject.SignalFlags.RUN_FIRST, None, ()),
-    }
-
     __gtype_name__ = 'PlayerToolbar'
 
     _artist_label = Gtk.Template.Child()
@@ -62,39 +58,64 @@ class PlayerToolbar(Gtk.ActionBar):
     _song_info_box = Gtk.Template.Child()
     _title_label = Gtk.Template.Child()
 
+    _repeat_dict = {
+        RepeatMode.ALL: "media-playlist-repeat-symbolic",
+        RepeatMode.NONE: "media-playlist-consecutive-symbolic",
+        RepeatMode.SHUFFLE: "media-playlist-shuffle-symbolic",
+        RepeatMode.SONG: "media-playlist-repeat-song-symbolic"
+    }
+
     def __repr__(self):
         return '<PlayerToolbar>'
 
     @log
-    def __init__(self, player, main_window):
+    def __init__(self):
         super().__init__()
 
-        self._main_window = main_window
-        self._player = player
-        self._progress_scale.props.player = self._player
+        self._player = None
 
         self._cover_stack.props.size = Art.Size.XSMALL
-        self._cover_stack.connect('updated', self._on_cover_stack_updated)
 
         self._tooltip = TwoLineTip()
 
-        self._sync_repeat_image()
+    # FIXME: This is a workaround for not being able to pass the player
+    # object via init when using Gtk.Builder.
+    @GObject.Property(type=Player, default=None)
+    def player(self):
+        """The GstPlayer object used
+
+        :return: player object
+        :rtype: GstPlayer
+        """
+        return self._player
+
+    @player.setter
+    def player(self, player):
+        """Set the GstPlayer object used
+
+        :param GstPlayer player: The GstPlayer to use
+        """
+        if (player is None
+                or (self._player is not None
+                    and self._player != player)):
+            return
+
+        self._player = player
+        self._progress_scale.props.player = self._player
 
         self._player.connect('song-changed', self._update_view)
         self._player.connect(
             'notify::repeat-mode', self._on_repeat_mode_changed)
         self._player.connect('notify::state', self._sync_playing)
 
+        self._sync_repeat_image()
+
     @Gtk.Template.Callback()
     @log
     def _on_progress_value_changed(self, progress_scale):
         seconds = int(progress_scale.get_value() / 60)
         self._progress_time_label.set_label(utils.seconds_to_string(seconds))
 
-    @log
-    def _on_cover_stack_updated(self, klass):
-        self.emit('thumbnail-updated')
-
     @Gtk.Template.Callback()
     @log
     def _on_prev_button_clicked(self, button):
@@ -117,23 +138,18 @@ class PlayerToolbar(Gtk.ActionBar):
 
     @log
     def _sync_repeat_image(self):
-        icon = None
-        repeat_mode = self._player.props.repeat_mode
-        if repeat_mode == RepeatMode.NONE:
-            icon = 'media-playlist-consecutive-symbolic'
-        elif repeat_mode == RepeatMode.SHUFFLE:
-            icon = 'media-playlist-shuffle-symbolic'
-        elif repeat_mode == RepeatMode.ALL:
-            icon = 'media-playlist-repeat-symbolic'
-        elif repeat_mode == RepeatMode.SONG:
-            icon = 'media-playlist-repeat-song-symbolic'
-
+        icon = self._repeat_dict[self._player.props.repeat_mode]
         self._repeat_image.set_from_icon_name(icon, Gtk.IconSize.MENU)
 
     @log
-    def _sync_playing(self, klass, args):
-        if not self._main_window.props.selection_mode:
-            self.show()
+    def _sync_playing(self, player, state):
+        if (self._player.props.state == Playback.STOPPED
+                and not self._player.props.has_next
+                and not self._player.props.has_previous):
+            self.hide()
+            return
+
+        self.show()
 
         if self._player.props.state == Playback.PLAYING:
             image = self._pause_image
@@ -153,21 +169,21 @@ class PlayerToolbar(Gtk.ActionBar):
         self._prev_button.props.sensitive = self._player.props.has_previous
 
     @log
-    def _update_view(self, player, position):
-        """Updates model when the song changes
+    def _update_view(self, player):
+        """Update all visual elements on song change
 
         :param Player player: The main player object
-        :param int position: current song position
         """
-        current_song = player.props.current_song
-        self._duration_label.set_label(
-            utils.seconds_to_string(current_song.get_duration()))
+        coresong = player.props.current_song
+        self._duration_label.props.label = utils.seconds_to_string(
+            coresong.props.duration)
+        self._progress_time_label.props.label = "0:00"
 
         self._play_button.set_sensitive(True)
         self._sync_prev_next()
 
-        artist = utils.get_artist_name(current_song)
-        title = utils.get_media_title(current_song)
+        artist = coresong.props.artist
+        title = coresong.props.title
 
         self._title_label.props.label = title
         self._artist_label.props.label = artist
@@ -175,7 +191,7 @@ class PlayerToolbar(Gtk.ActionBar):
         self._tooltip.props.title = title
         self._tooltip.props.subtitle = artist
 
-        self._cover_stack.update(current_song)
+        self._cover_stack.update(coresong)
 
     @Gtk.Template.Callback()
     @log
